@@ -1,7 +1,7 @@
 // qsynthKnob.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This widget is based on a design by Thorsten Wilms, 
    implemented by Chris Cannam in Rosegarden,
@@ -23,19 +23,12 @@
 
 *****************************************************************************/
 
+#include "qsynthAbout.h"
 #include "qsynthKnob.h"
 
-#include <QTimer>
-#include <QToolTip>
-#include <QPainter>
-#include <QImage>
-
 #include <QMouseEvent>
 #include <QWheelEvent>
 
-#include <QRadialGradient>
-#include <QColormap>
-
 #include <cmath>
 
 
@@ -43,15 +36,10 @@
 // qsynthKnob - Instance knob widget class.
 //
 
-#define QSYNTH_KNOB_MIN      (0.25 * M_PI)
-#define QSYNTH_KNOB_MAX      (1.75 * M_PI)
-#define QSYNTH_KNOB_RANGE    (QSYNTH_KNOB_MAX - QSYNTH_KNOB_MIN)
-
-
 // Constructor.
 qsynthKnob::qsynthKnob ( QWidget *pParent )
-	: QDial(pParent), m_iDefaultValue(-1), m_dialMode(AngularMode),
-	m_bMousePressed(false), m_lastDragValue(0.0)
+	: QDial(pParent), m_iDefaultValue(-1), m_dialMode(DefaultMode),
+	m_bMousePressed(false), m_fLastDragValue(0.0f)
 {
 }
 
@@ -74,36 +62,36 @@ void qsynthKnob::setDialMode ( qsynthKnob::DialMode dialMode )
 
 
 // Mouse angle determination.
-double qsynthKnob::mouseAngle ( const QPoint& pos )
+float qsynthKnob::mouseAngle ( const QPoint& pos )
 {
-	double dx = pos.x() - (width() / 2);
-	double dy = (height() / 2) - pos.y();
-	return 180.0 * atan2(dx, dy) / M_PI;
+	float dx = pos.x() - (width() / 2);
+	float dy = (height() / 2) - pos.y();
+	return 180.0f * atan2f(dx, dy) / float(M_PI);
 }
 
 
 // Alternate mouse behavior event handlers.
 void qsynthKnob::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
-	if (m_dialMode == QDialMode) {
-		QDial::mousePressEvent(pMouseEvent);
-	} else if (pMouseEvent->button() == Qt::LeftButton) {
-		m_bMousePressed = true;
-		m_posMouse = pMouseEvent->pos();
-		m_lastDragValue = double(value());
-		emit sliderPressed();
-	} else if (pMouseEvent->button() == Qt::MidButton) {
+	if (pMouseEvent->button() == Qt::MidButton) {
 		// Reset to default value...
 		if (m_iDefaultValue < minimum() || m_iDefaultValue > maximum())
 			m_iDefaultValue = (maximum() + minimum()) / 2;
 		setValue(m_iDefaultValue);
+	} else if (m_dialMode == DefaultMode) {
+		QDial::mousePressEvent(pMouseEvent);
+	} else if (pMouseEvent->button() == Qt::LeftButton) {
+		m_bMousePressed = true;
+		m_posMouse = pMouseEvent->pos();
+		m_fLastDragValue = float(value());
+		emit sliderPressed();
 	}
 }
 
 
 void qsynthKnob::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 {
-	if (m_dialMode == QDialMode) {
+	if (m_dialMode == DefaultMode) {
 		QDial::mouseMoveEvent(pMouseEvent);
 		return;
 	}
@@ -111,29 +99,31 @@ void qsynthKnob::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 	if (!m_bMousePressed)
 		return;
 
-	const QPoint& posMouse = pMouseEvent->pos();
-	int xdelta = posMouse.x() - m_posMouse.x();
-	int ydelta = posMouse.y() - m_posMouse.y();
-	double angleDelta =  mouseAngle(posMouse) - mouseAngle(m_posMouse);
+	const QPoint& pos = pMouseEvent->pos();
+	int xdelta = pos.x() - m_posMouse.x();
+	int ydelta = pos.y() - m_posMouse.y();
+	float fAngleDelta =  mouseAngle(pos) - mouseAngle(m_posMouse);
 
 	int iNewValue = value();
 
 	switch (m_dialMode)	{
 	case LinearMode:
-		iNewValue = int(m_lastDragValue + xdelta - ydelta);
+		iNewValue = int(m_fLastDragValue) + xdelta - ydelta;
 		break;
 	case AngularMode:
 	default:
 		// Forget about the drag origin to be robust on full rotations
-		if (angleDelta > +180.0) angleDelta = angleDelta - 360.0;
-		if (angleDelta < -180.0) angleDelta = angleDelta + 360.0;
-		m_lastDragValue += double(maximum() - minimum()) * angleDelta / 270.0;
-		if (m_lastDragValue > double(maximum()))
-			m_lastDragValue = double(maximum());
-		if (m_lastDragValue < double(minimum()))
-			m_lastDragValue = double(minimum());
-		m_posMouse = posMouse;
-		iNewValue = int(m_lastDragValue + 0.5);
+		if (fAngleDelta > +180.0f) fAngleDelta -= 360.0f;
+		else
+		if (fAngleDelta < -180.0f) fAngleDelta += 360.0f;
+		m_fLastDragValue += float(maximum() - minimum()) * fAngleDelta / 270.0f;
+		if (m_fLastDragValue > float(maximum()))
+			m_fLastDragValue = float(maximum());
+		else
+		if (m_fLastDragValue < float(minimum()))
+			m_fLastDragValue = float(minimum());
+		m_posMouse = pos;
+		iNewValue = int(m_fLastDragValue + 0.5f);
 		break;
 	}
 
@@ -146,7 +136,7 @@ void qsynthKnob::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 
 void qsynthKnob::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 {
-	if (m_dialMode == QDialMode) {
+	if (m_dialMode == DefaultMode && pMouseEvent->button() != Qt::MidButton) {
 		QDial::mouseReleaseEvent(pMouseEvent);
 	} else if (m_bMousePressed) {
 		m_bMousePressed = false;
@@ -156,7 +146,7 @@ void qsynthKnob::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 
 void qsynthKnob::wheelEvent ( QWheelEvent *pWheelEvent )
 {
-	if (m_dialMode == QDialMode) {
+	if (m_dialMode == DefaultMode) {
 		QDial::wheelEvent(pWheelEvent);
 	} else {
 		int iValue = value();
