@@ -1,7 +1,7 @@
 // qsynthMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -53,14 +53,32 @@
 #include <QDragEnterEvent>
 #include <QDropEvent>
 
+#if QT_VERSION < 0x040500
+namespace Qt {
+const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
+#if QT_VERSION < 0x040200
+const WindowFlags CustomizeWindowHint   = WindowFlags(0x02000000);
+#endif
+}
+#endif
+
+
 // Timer constant stuff.
 #define QSYNTH_TIMER_MSECS  100
 #define QSYNTH_DELAY_MSECS  200
 
 // Scale factors.
-#define QSYNTH_GAIN_SCALE   100.0f
-#define QSYNTH_REVERB_SCALE 100.0f
-#define QSYNTH_CHORUS_SCALE 10.0f
+#define QSYNTH_MASTER_GAIN_SCALE    100.0f
+
+#define QSYNTH_REVERB_ROOM_SCALE    100.0f
+#define QSYNTH_REVERB_DAMP_SCALE	100.0f
+#define QSYNTH_REVERB_WIDTH_SCALE   1.0f
+#define QSYNTH_REVERB_LEVEL_SCALE   100.0f
+
+#define QSYNTH_CHORUS_NR_SCALE      1.0f
+#define QSYNTH_CHORUS_LEVEL_SCALE   100.0f
+#define QSYNTH_CHORUS_SPEED_SCALE   100.0f
+#define QSYNTH_CHORUS_DEPTH_SCALE   10.0f
 
 #if defined(WIN32)
 #undef HAVE_SIGNAL_H
@@ -543,15 +561,11 @@ void qsynthMainForm::setup ( qsynthOptions *pOptions )
 	// What style do we create these forms?
 	QWidget *pParent = NULL;
 	Qt::WindowFlags wflags = Qt::Window
-#if QT_VERSION >= 0x040200
- 		| Qt::CustomizeWindowHint
-#if QT_VERSION >= 0x040500
-		| Qt::WindowCloseButtonHint
-#endif
-#endif
+		| Qt::CustomizeWindowHint
 		| Qt::WindowTitleHint
 		| Qt::WindowSystemMenuHint
-		| Qt::WindowMinMaxButtonsHint;
+		| Qt::WindowMinMaxButtonsHint
+		| Qt::WindowCloseButtonHint;
 	if (m_pOptions->bKeepOnTop) {
 		pParent = this;
 		wflags |= Qt::Tool;
@@ -572,7 +586,7 @@ void qsynthMainForm::setup ( qsynthOptions *pOptions )
 		m_ui.TabBar->addEngine(new qsynthEngine(m_pOptions, iter.next()));
 
 	// Try to restore old window positioning.
-	m_pOptions->loadWidgetGeometry(this, m_pOptions->bStartMinimized);
+	m_pOptions->loadWidgetGeometry(this, true);
 
 	// And for the whole widget gallore...
 	m_pOptions->loadWidgetGeometry(m_pMessagesForm);
@@ -632,12 +646,22 @@ bool qsynthMainForm::queryClose (void)
 		// active system tray icon, then just hide ourselves.
 		if (!m_bQuitForce && isVisible()
 			&& m_pOptions->bSystemTray && m_pSystemTray) {
-			m_pOptions->saveWidgetGeometry(this);
-			QMessageBox::information(this,
-				QSYNTH_TITLE ": " + tr("Information"),
-				tr("The program will keep running in the system tray.\n\n"
-				"To terminate the program, please choose \"Quit\" "
-				"in the context menu of the system tray entry."));
+			m_pOptions->saveWidgetGeometry(this, true);
+			const QString& sTitle = QSYNTH_TITLE ": " + tr("Information");
+			const QString& sText
+				= tr("The program will keep running in the system tray.\n\n"
+					"To terminate the program, please choose \"Quit\"\n"
+					"in the context menu of the system tray icon.");
+		#ifdef QSYNTH_QT4_SYSTEM_TRAY
+		#if QT_VERSION >= 0x040300
+			if (QSystemTrayIcon::supportsMessages()) {
+				m_pSystemTray->showMessage(
+					sTitle, sText, QSystemTrayIcon::Information);
+			}
+			else
+		#endif
+		#endif
+			QMessageBox::information(this, sTitle, sText);
 			hide();
 			bQueryClose = false;
 		}
@@ -664,7 +688,7 @@ bool qsynthMainForm::queryClose (void)
 		if (bQueryClose) {
 			m_pOptions->saveWidgetGeometry(m_pChannelsForm);
 			m_pOptions->saveWidgetGeometry(m_pMessagesForm);
-			m_pOptions->saveWidgetGeometry(this);
+			m_pOptions->saveWidgetGeometry(this, true);
 			// Close popup widgets.
 			if (m_pMessagesForm)
 				m_pMessagesForm->close();
@@ -882,8 +906,19 @@ void qsynthMainForm::appendMessagesError( const QString& s )
 
 	appendMessagesColor(s.simplified(), "#ff0000");
 
-	QMessageBox::critical(this,
-		QSYNTH_TITLE ": " + tr("Error"), s, QMessageBox::Cancel);
+	const QString& sTitle = QSYNTH_TITLE ": " + tr("Error");
+#ifdef CONFIG_SYSTEM_TRAY
+#ifdef QSYNTH_QT4_SYSTEM_TRAY
+#if QT_VERSION >= 0x040300
+	if (m_pOptions->bSystemTray && m_pSystemTray
+		&& QSystemTrayIcon::supportsMessages()) {
+		m_pSystemTray->showMessage(sTitle, s, QSystemTrayIcon::Critical);
+	}
+	else
+#endif
+#endif
+#endif
+	QMessageBox::critical(this, sTitle, s, QMessageBox::Cancel);
 }
 
 
@@ -981,29 +1016,29 @@ void qsynthMainForm::systemTrayContextMenu ( const QPoint& pos )
 	menu.addSeparator();
 
 	qsynthEngine *pEngine = currentEngine();
-	pAction = menu.addAction(QIcon(":/icons/add1.png"),
+	pAction = menu.addAction(QIcon(":/images/add1.png"),
 		tr("&New engine..."), this, SLOT(newEngine()));
-	pAction = menu.addAction(QIcon(":/icons/remove1.png"),
+	pAction = menu.addAction(QIcon(":/images/remove1.png"),
 		tr("&Delete"), this, SLOT(deleteEngine()));
 	pAction->setEnabled(pEngine && !pEngine->isDefault());
 	menu.addSeparator();
 
 	bool bEnabled = (pEngine && pEngine->pSynth);
-	pAction = menu.addAction(QIcon(":/icons/restart1.png"),
+	pAction = menu.addAction(QIcon(":/images/restart1.png"),
 		bEnabled ? tr("Re&start") : tr("&Start"), this, SLOT(promptRestart()));
-	pAction = menu.addAction(QIcon(":/icons/reset1.png"),
+	pAction = menu.addAction(QIcon(":/images/reset1.png"),
 		tr("&Reset"), this, SLOT(programReset()));
 	pAction->setEnabled(bEnabled);
-	pAction = menu.addAction(QIcon(":/icons/panic1.png"),
+	pAction = menu.addAction(QIcon(":/images/panic1.png"),
 		tr("&Panic"), this, SLOT(systemReset()));
 	pAction->setEnabled(bEnabled);
 	menu.addSeparator();
-	pAction = menu.addAction(QIcon(":/icons/channels1.png"),
+	pAction = menu.addAction(QIcon(":/images/channels1.png"),
 		tr("&Channels"), this, SLOT(toggleChannelsForm()));
 	pAction->setCheckable(true);
 	pAction->setChecked(m_pChannelsForm && m_pChannelsForm->isVisible());
 	pAction->setEnabled(bEnabled);
-	pAction = menu.addAction(QIcon(":/icons/setup1.png"),
+	pAction = menu.addAction(QIcon(":/images/setup1.png"),
 		tr("Set&up..."), this, SLOT(showSetupForm()));
 	menu.addSeparator();
 
@@ -1025,17 +1060,17 @@ void qsynthMainForm::systemTrayContextMenu ( const QPoint& pos )
 		SLOT(activateEnginesMenu(QAction*)));
 	menu.addSeparator();
 
-	pAction = menu.addAction(QIcon(":/icons/messages1.png"),
+	pAction = menu.addAction(QIcon(":/images/messages1.png"),
 		tr("&Messages"), this, SLOT(toggleMessagesForm()));
 	pAction->setCheckable(true);
 	pAction->setChecked(m_pMessagesForm && m_pMessagesForm->isVisible());
-	pAction = menu.addAction(QIcon(":/icons/options1.png"),
+	pAction = menu.addAction(QIcon(":/images/options1.png"),
 		tr("&Options..."), this, SLOT(showOptionsForm()));
-//  pAction = menu.AddAction(QIcon(":/icons/about1.png"),
+//  pAction = menu.AddAction(QIcon(":/images/about1.png"),
 //      tr("A&bout..."), this, SLOT(showAboutForm()));
 	menu.addSeparator();
 
-	pAction = menu.addAction(QIcon(":/icons/quit1.png"),
+	pAction = menu.addAction(QIcon(":/images/quit1.png"),
 		tr("&Quit"), this, SLOT(quitMainForm()));
 
 	menu.exec(pos);
@@ -1264,7 +1299,8 @@ void qsynthMainForm::toggleMainForm (void)
 	if (m_pOptions == NULL)
 		return;
 
-	m_pOptions->saveWidgetGeometry(this);
+	m_pOptions->saveWidgetGeometry(this, true);
+
 	if (isVisible()) {
 		if (m_pOptions->bSystemTray && m_pSystemTray) {
 			// Hide away from sight.
@@ -1362,10 +1398,24 @@ void qsynthMainForm::showOptionsForm (void)
 				( bKeepOnTop     && !m_pOptions->bKeepOnTop)     ||
 				(!bKeepOnTop     &&  m_pOptions->bKeepOnTop)     ||
 				(iOldBaseFontSize != m_pOptions->iBaseFontSize)) {
-				QMessageBox::information(this,
-					QSYNTH_TITLE ": " + tr("Information"),
-					tr("Some settings will be only effective\n"
-					"next time you start this program."));
+				const QString& sTitle
+					= QSYNTH_TITLE ": " + tr("Information");
+				const QString& sText
+					= tr("Some settings will be only effective\n"
+						"next time you start this program.");
+			#ifdef CONFIG_SYSTEM_TRAY
+			#ifdef QSYNTH_QT4_SYSTEM_TRAY
+			#if QT_VERSION >= 0x040300
+				if (m_pOptions->bSystemTray && m_pSystemTray
+					&& QSystemTrayIcon::supportsMessages()) {
+					m_pSystemTray->showMessage(
+						sTitle, sText, QSystemTrayIcon::Information);
+				}
+				else
+			#endif
+			#endif
+			#endif
+				QMessageBox::information(this, sTitle, sText);
 			}
 			// Check wheather something immediate has changed.
 			if (( bOldMessagesLog && !m_pOptions->bMessagesLog) ||
@@ -1453,13 +1503,13 @@ void qsynthMainForm::tabContextMenu ( int iTab, const QPoint& pos )
 	QMenu menu(this);
 	QAction *pAction;
 
-	pAction = menu.addAction(QIcon(":/icons/add1.png"),
+	pAction = menu.addAction(QIcon(":/images/add1.png"),
 		tr("&New engine..."), this, SLOT(newEngine()));
-	pAction = menu.addAction(QIcon(":/icons/remove1.png"),
+	pAction = menu.addAction(QIcon(":/images/remove1.png"),
 		tr("&Delete"), this, SLOT(deleteEngine()));
 	pAction->setEnabled(pEngine && !pEngine->isDefault());
 	menu.addSeparator();
-	pAction = menu.addAction(QIcon(":/icons/setup1.png"),
+	pAction = menu.addAction(QIcon(":/images/setup1.png"),
 		tr("Set&up..."), this, SLOT(showSetupForm()));
 	pAction->setEnabled(pEngine != NULL);
 
@@ -2058,27 +2108,27 @@ void qsynthMainForm::loadPanelSettings ( qsynthEngine *pEngine, bool bUpdate )
 	m_iChorusUpdated = 1;
 
 	m_ui.GainDial->setDefaultValue(qsynth_set_range_value(
-		m_ui.GainDial, QSYNTH_GAIN_SCALE, pSetup->fGain));
+		m_ui.GainDial, QSYNTH_MASTER_GAIN_SCALE, pSetup->fGain));
 
 	m_ui.ReverbActiveCheckBox->setChecked(pSetup->bReverbActive);
 	m_ui.ReverbRoomDial->setDefaultValue(qsynth_set_range_value(
-		m_ui.ReverbRoomDial,  QSYNTH_REVERB_SCALE, pSetup->fReverbRoom));
+		m_ui.ReverbRoomDial, QSYNTH_REVERB_ROOM_SCALE, pSetup->fReverbRoom));
 	m_ui.ReverbDampDial->setDefaultValue(qsynth_set_range_value(
-		m_ui.ReverbDampDial,  QSYNTH_REVERB_SCALE, pSetup->fReverbDamp));
+		m_ui.ReverbDampDial, QSYNTH_REVERB_DAMP_SCALE, pSetup->fReverbDamp));
 	m_ui.ReverbWidthDial->setDefaultValue(qsynth_set_range_value(
-		m_ui.ReverbWidthDial, QSYNTH_REVERB_SCALE, pSetup->fReverbWidth));
+		m_ui.ReverbWidthDial, QSYNTH_REVERB_WIDTH_SCALE, pSetup->fReverbWidth));
 	m_ui.ReverbLevelDial->setDefaultValue(qsynth_set_range_value(
-		m_ui.ReverbLevelDial, QSYNTH_REVERB_SCALE, pSetup->fReverbLevel));
+		m_ui.ReverbLevelDial, QSYNTH_REVERB_LEVEL_SCALE, pSetup->fReverbLevel));
 
 	m_ui.ChorusActiveCheckBox->setChecked(pSetup->bChorusActive);
 	m_ui.ChorusNrDial->setDefaultValue(pSetup->iChorusNr);
 	m_ui.ChorusNrDial->setValue(pSetup->iChorusNr);
 	m_ui.ChorusLevelDial->setDefaultValue(qsynth_set_range_value(
-		m_ui.ChorusLevelDial, QSYNTH_CHORUS_SCALE, pSetup->fChorusLevel));
+		m_ui.ChorusLevelDial, QSYNTH_CHORUS_LEVEL_SCALE, pSetup->fChorusLevel));
 	m_ui.ChorusSpeedDial->setDefaultValue(qsynth_set_range_value(
-		m_ui.ChorusSpeedDial, QSYNTH_CHORUS_SCALE, pSetup->fChorusSpeed));
+		m_ui.ChorusSpeedDial, QSYNTH_CHORUS_SPEED_SCALE, pSetup->fChorusSpeed));
 	m_ui.ChorusDepthDial->setDefaultValue(qsynth_set_range_value(
-		m_ui.ChorusDepthDial, QSYNTH_CHORUS_SCALE, pSetup->fChorusDepth));
+		m_ui.ChorusDepthDial, QSYNTH_CHORUS_DEPTH_SCALE, pSetup->fChorusDepth));
 	m_ui.ChorusTypeComboBox->setCurrentIndex(pSetup->iChorusType);
 
 	// Make them dirty.
@@ -2107,19 +2157,27 @@ void qsynthMainForm::savePanelSettings ( qsynthEngine *pEngine )
 	if (pSetup == NULL)
 		return;
 
-	pSetup->fGain = qsynth_get_range_value(m_ui.GainSpinBox, QSYNTH_GAIN_SCALE);
+	pSetup->fGain = qsynth_get_range_value(
+		m_ui.GainSpinBox, QSYNTH_MASTER_GAIN_SCALE);
 
 	pSetup->bReverbActive = m_ui.ReverbActiveCheckBox->isChecked();
-	pSetup->fReverbRoom   = qsynth_get_range_value(m_ui.ReverbRoomSpinBox,  QSYNTH_REVERB_SCALE);
-	pSetup->fReverbDamp   = qsynth_get_range_value(m_ui.ReverbDampSpinBox,  QSYNTH_REVERB_SCALE);
-	pSetup->fReverbWidth  = qsynth_get_range_value(m_ui.ReverbWidthSpinBox, QSYNTH_REVERB_SCALE);
-	pSetup->fReverbLevel  = qsynth_get_range_value(m_ui.ReverbLevelSpinBox, QSYNTH_REVERB_SCALE);
+	pSetup->fReverbRoom   = qsynth_get_range_value(
+		m_ui.ReverbRoomSpinBox, QSYNTH_REVERB_ROOM_SCALE);
+	pSetup->fReverbDamp   = qsynth_get_range_value(
+		m_ui.ReverbDampSpinBox, QSYNTH_REVERB_DAMP_SCALE);
+	pSetup->fReverbWidth  = qsynth_get_range_value(
+		m_ui.ReverbWidthSpinBox, QSYNTH_REVERB_WIDTH_SCALE);
+	pSetup->fReverbLevel  = qsynth_get_range_value(
+		m_ui.ReverbLevelSpinBox, QSYNTH_REVERB_LEVEL_SCALE);
 
 	pSetup->bChorusActive = m_ui.ChorusActiveCheckBox->isChecked();
 	pSetup->iChorusNr     = m_ui.ChorusNrSpinBox->value();
-	pSetup->fChorusLevel  = qsynth_get_range_value(m_ui.ChorusLevelSpinBox, QSYNTH_CHORUS_SCALE);
-	pSetup->fChorusSpeed  = qsynth_get_range_value(m_ui.ChorusSpeedSpinBox, QSYNTH_CHORUS_SCALE);
-	pSetup->fChorusDepth  = qsynth_get_range_value(m_ui.ChorusDepthSpinBox, QSYNTH_CHORUS_SCALE);
+	pSetup->fChorusLevel  = qsynth_get_range_value(
+		m_ui.ChorusLevelSpinBox, QSYNTH_CHORUS_LEVEL_SCALE);
+	pSetup->fChorusSpeed  = qsynth_get_range_value(
+		m_ui.ChorusSpeedSpinBox, QSYNTH_CHORUS_SPEED_SCALE);
+	pSetup->fChorusDepth  = qsynth_get_range_value(
+		m_ui.ChorusDepthSpinBox, QSYNTH_CHORUS_DEPTH_SCALE);
 	pSetup->iChorusType   = m_ui.ChorusTypeComboBox->currentIndex();
 }
 
@@ -2232,7 +2290,8 @@ void qsynthMainForm::updateGain (void)
 		return;
 	m_iGainUpdated++;
 
-	float fGain = qsynth_get_range_value(m_ui.GainSpinBox, QSYNTH_GAIN_SCALE);
+	float fGain = qsynth_get_range_value(
+		m_ui.GainSpinBox, QSYNTH_MASTER_GAIN_SCALE);
 
 	setEngineGain(pEngine, fGain);
 	refreshGain();
@@ -2255,10 +2314,14 @@ void qsynthMainForm::updateReverb (void)
 		return;
 	m_iReverbUpdated++;
 
-	double fReverbRoom  = qsynth_get_range_value(m_ui.ReverbRoomSpinBox,  QSYNTH_REVERB_SCALE);
-	double fReverbDamp  = qsynth_get_range_value(m_ui.ReverbDampSpinBox,  QSYNTH_REVERB_SCALE);
-	double fReverbWidth = qsynth_get_range_value(m_ui.ReverbWidthSpinBox, QSYNTH_REVERB_SCALE);
-	double fReverbLevel = qsynth_get_range_value(m_ui.ReverbLevelSpinBox, QSYNTH_REVERB_SCALE);
+	double fReverbRoom  = qsynth_get_range_value(
+		m_ui.ReverbRoomSpinBox, QSYNTH_REVERB_ROOM_SCALE);
+	double fReverbDamp  = qsynth_get_range_value(
+		m_ui.ReverbDampSpinBox, QSYNTH_REVERB_DAMP_SCALE);
+	double fReverbWidth = qsynth_get_range_value(
+		m_ui.ReverbWidthSpinBox, QSYNTH_REVERB_WIDTH_SCALE);
+	double fReverbLevel = qsynth_get_range_value(
+		m_ui.ReverbLevelSpinBox, QSYNTH_REVERB_LEVEL_SCALE);
 
 	setEngineReverb(pEngine, fReverbRoom, fReverbDamp, fReverbWidth, fReverbLevel);
 	refreshReverb();
@@ -2282,9 +2345,12 @@ void qsynthMainForm::updateChorus (void)
 	m_iChorusUpdated++;
 
 	int    iChorusNr    = m_ui.ChorusNrSpinBox->value();
-	double fChorusLevel = qsynth_get_range_value(m_ui.ChorusLevelSpinBox, QSYNTH_CHORUS_SCALE);
-	double fChorusSpeed = qsynth_get_range_value(m_ui.ChorusSpeedSpinBox, QSYNTH_CHORUS_SCALE);
-	double fChorusDepth = qsynth_get_range_value(m_ui.ChorusDepthSpinBox, QSYNTH_CHORUS_SCALE);
+	double fChorusLevel = qsynth_get_range_value(
+		m_ui.ChorusLevelSpinBox, QSYNTH_CHORUS_LEVEL_SCALE);
+	double fChorusSpeed = qsynth_get_range_value(
+		m_ui.ChorusSpeedSpinBox, QSYNTH_CHORUS_SPEED_SCALE);
+	double fChorusDepth = qsynth_get_range_value(
+		m_ui.ChorusDepthSpinBox, QSYNTH_CHORUS_DEPTH_SCALE);
 	int    iChorusType  = m_ui.ChorusTypeComboBox->currentIndex();
 
 	setEngineChorus(pEngine, iChorusNr, fChorusLevel, fChorusSpeed, fChorusDepth, iChorusType);
@@ -2306,7 +2372,8 @@ void qsynthMainForm::refreshGain (void)
 
 	float fGain = ::fluid_synth_get_gain(pEngine->pSynth);
 
-	qsynth_set_range_value(m_ui.GainDial, QSYNTH_GAIN_SCALE, fGain);
+	qsynth_set_range_value(
+		m_ui.GainDial, QSYNTH_MASTER_GAIN_SCALE, fGain);
 }
 
 
@@ -2324,10 +2391,14 @@ void qsynthMainForm::refreshReverb (void)
 	double fReverbWidth = ::fluid_synth_get_reverb_width(pEngine->pSynth);
 	double fReverbLevel = ::fluid_synth_get_reverb_level(pEngine->pSynth);
 
-	qsynth_set_range_value(m_ui.ReverbRoomDial,  QSYNTH_REVERB_SCALE, fReverbRoom);
-	qsynth_set_range_value(m_ui.ReverbDampDial,  QSYNTH_REVERB_SCALE, fReverbDamp);
-	qsynth_set_range_value(m_ui.ReverbWidthDial, QSYNTH_REVERB_SCALE, fReverbWidth);
-	qsynth_set_range_value(m_ui.ReverbLevelDial, QSYNTH_REVERB_SCALE, fReverbLevel);
+	qsynth_set_range_value(
+		m_ui.ReverbRoomDial, QSYNTH_REVERB_ROOM_SCALE, fReverbRoom);
+	qsynth_set_range_value(
+		m_ui.ReverbDampDial, QSYNTH_REVERB_DAMP_SCALE, fReverbDamp);
+	qsynth_set_range_value(
+		m_ui.ReverbWidthDial, QSYNTH_REVERB_WIDTH_SCALE, fReverbWidth);
+	qsynth_set_range_value(
+		m_ui.ReverbLevelDial, QSYNTH_REVERB_LEVEL_SCALE, fReverbLevel);
 }
 
 
@@ -2347,9 +2418,12 @@ void qsynthMainForm::refreshChorus (void)
 	int    iChorusType  = ::fluid_synth_get_chorus_type(pEngine->pSynth);
 
 	m_ui.ChorusNrDial->setValue(iChorusNr);
-	qsynth_set_range_value(m_ui.ChorusLevelDial, QSYNTH_CHORUS_SCALE, fChorusLevel);
-	qsynth_set_range_value(m_ui.ChorusSpeedDial, QSYNTH_CHORUS_SCALE, fChorusSpeed);
-	qsynth_set_range_value(m_ui.ChorusDepthDial, QSYNTH_CHORUS_SCALE, fChorusDepth);
+	qsynth_set_range_value(
+		m_ui.ChorusLevelDial, QSYNTH_CHORUS_LEVEL_SCALE, fChorusLevel);
+	qsynth_set_range_value(
+		m_ui.ChorusSpeedDial, QSYNTH_CHORUS_SPEED_SCALE, fChorusSpeed);
+	qsynth_set_range_value(
+		m_ui.ChorusDepthDial, QSYNTH_CHORUS_DEPTH_SCALE, fChorusDepth);
 	m_ui.ChorusTypeComboBox->setCurrentIndex(iChorusType);
 }
 
