@@ -1,7 +1,7 @@
 // qsynthOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -41,6 +41,24 @@ qsynthOptions::qsynthOptions (void)
 	// Load previous/default fluidsynth settings...
 	loadSetup(m_pDefaultSetup, QString::null);
 
+	loadOptions();
+}
+
+
+// Default Destructor.
+qsynthOptions::~qsynthOptions (void)
+{
+	saveOptions();
+
+	// Delete default setup descriptor.
+	delete m_pDefaultSetup;
+	m_pDefaultSetup = NULL;
+}
+
+
+// Explicit load method.
+void qsynthOptions::loadOptions (void)
+{
 	// Load display options...
 	m_settings.beginGroup("/Options");
 	sMessagesFont   = m_settings.value("/MessagesFont").toString();
@@ -79,8 +97,8 @@ qsynthOptions::qsynthOptions (void)
 }
 
 
-// Default Destructor.
-qsynthOptions::~qsynthOptions (void)
+// Explicit save method.
+void qsynthOptions::saveOptions (void)
 {
 	// Make program version available in the future.
 	m_settings.beginGroup("/Program");
@@ -124,9 +142,8 @@ qsynthOptions::~qsynthOptions (void)
 	m_settings.setValue("/KnobMotion", iKnobMotion);
 	m_settings.endGroup();
 
-	// Create default setup descriptor.
-	delete m_pDefaultSetup;
-	m_pDefaultSetup = NULL;
+	// Save/commit to disk.
+	m_settings.sync();
 }
 
 
@@ -647,9 +664,14 @@ bool qsynthOptions::loadPreset ( qsynthEngine *pEngine, const QString& sPreset )
 	for (int iChan = 0; iChan < iChannels; iChan++) {
 		QString sEntry = m_settings.value(sPrefix.arg(iChan + 1)).toString();
 		if (!sEntry.isEmpty() && iChan == sEntry.section(':', 0, 0).toInt()) {
-			::fluid_synth_bank_select(pEngine->pSynth, iChan, sEntry.section(':', 1, 1).toInt());
-			::fluid_synth_program_change(pEngine->pSynth, iChan, sEntry.section(':', 2, 2).toInt());
+			::fluid_synth_bank_select(pEngine->pSynth, iChan,
+				sEntry.section(':', 1, 1).toInt());
+			::fluid_synth_program_change(pEngine->pSynth, iChan,
+				sEntry.section(':', 2, 2).toInt());
 		}
+	#ifdef CONFIG_FLUID_UNSET_PROGRAM
+		else ::fluid_synth_unset_program(pEngine->pSynth, iChan);
+	#endif
 	}
 	m_settings.endGroup();
 
@@ -690,12 +712,28 @@ bool qsynthOptions::savePreset ( qsynthEngine *pEngine, const QString& sPreset )
 	int iChannels = ::fluid_synth_count_midi_channels(pEngine->pSynth);
 	int iChan = 0;
 	for ( ; iChan < iChannels; iChan++) {
+	#ifdef CONFIG_FLUID_CHANNEL_INFO
+		fluid_synth_channel_info_t info;
+		::memset(&info, 0, sizeof(info));
+		::fluid_synth_get_channel_info(pEngine->pSynth, iChan, &info);
+		if (info.assigned) {
+		#ifdef CONFIG_FLUID_BANK_OFFSET
+			info.bank += ::fluid_synth_get_bank_offset(pEngine->pSynth, info.sfont_id);
+		#endif
+			QString sEntry = QString::number(iChan);
+			sEntry += ':';
+			sEntry += QString::number(info.bank);
+			sEntry += ':';
+			sEntry += QString::number(info.program);
+			m_settings.setValue(sPrefix.arg(iChan + 1), sEntry);
+		}
+	#else
 		fluid_preset_t *pPreset = ::fluid_synth_get_channel_preset(pEngine->pSynth, iChan);
 		if (pPreset) {
 			int iBank = pPreset->get_banknum(pPreset);
-#ifdef CONFIG_FLUID_BANK_OFFSET
+		#ifdef CONFIG_FLUID_BANK_OFFSET
 			iBank += ::fluid_synth_get_bank_offset(pEngine->pSynth, (pPreset->sfont)->id);
-#endif
+		#endif
 			QString sEntry = QString::number(iChan);
 			sEntry += ':';
 			sEntry += QString::number(iBank);
@@ -703,6 +741,8 @@ bool qsynthOptions::savePreset ( qsynthEngine *pEngine, const QString& sPreset )
 			sEntry += QString::number(pPreset->get_num(pPreset));
 			m_settings.setValue(sPrefix.arg(iChan + 1), sEntry);
 		}
+	#endif
+		else m_settings.remove(sPrefix.arg(iChan + 1));
 	}
 	// Cleanup old entries, if any...
 	while (!m_settings.value(sPrefix.arg(++iChan)).toString().isEmpty())
@@ -801,27 +841,26 @@ void qsynthOptions::saveComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 //---------------------------------------------------------------------------
 // Widget geometry persistence helper methods.
 
-void qsynthOptions::loadWidgetGeometry ( QWidget *pWidget, bool bMinimized )
+void qsynthOptions::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 {
 	// Try to restore old form window positioning.
 	if (pWidget) {
-		QPoint fpos;
-		QSize  fsize;
-		bool bVisible;
+		QPoint wpos;
+		QSize  wsize;
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-		fpos.setX(m_settings.value("/x", -1).toInt());
-		fpos.setY(m_settings.value("/y", -1).toInt());
-		fsize.setWidth(m_settings.value("/width", -1).toInt());
-		fsize.setHeight(m_settings.value("/height", -1).toInt());
-		bVisible = m_settings.value("/visible", false).toBool();
+		wpos.setX(m_settings.value("/x", -1).toInt());
+		wpos.setY(m_settings.value("/y", -1).toInt());
+		wsize.setWidth(m_settings.value("/width", -1).toInt());
+		wsize.setHeight(m_settings.value("/height", -1).toInt());
+		if (!bVisible) bVisible = m_settings.value("/visible", false).toBool();
 		m_settings.endGroup();
-		if (fpos.x() > 0 && fpos.y() > 0)
-			pWidget->move(fpos);
-		if (fsize.width() > 0 && fsize.height() > 0)
-			pWidget->resize(fsize);
+		if (wpos.x() > 0 && wpos.y() > 0)
+			pWidget->move(wpos);
+		if (wsize.width() > 0 && wsize.height() > 0)
+			pWidget->resize(wsize);
 		else
 			pWidget->adjustSize();
-		if (bVisible && !bMinimized)
+		if (bVisible && !bStartMinimized)
 			pWidget->show();
 		else
 			pWidget->hide();
@@ -829,21 +868,21 @@ void qsynthOptions::loadWidgetGeometry ( QWidget *pWidget, bool bMinimized )
 }
 
 
-void qsynthOptions::saveWidgetGeometry ( QWidget *pWidget, bool bMinimized )
+void qsynthOptions::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 {
 	// Try to save form window position...
 	// (due to X11 window managers ideossincrasies, we better
 	// only save the form geometry while its up and visible)
 	if (pWidget) {
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-		bool bVisible = pWidget->isVisible();
-		const QPoint& fpos  = pWidget->pos();
-		const QSize&  fsize = pWidget->size();
-		m_settings.setValue("/x", fpos.x());
-		m_settings.setValue("/y", fpos.y());
-		m_settings.setValue("/width", fsize.width());
-		m_settings.setValue("/height", fsize.height());
-		m_settings.setValue("/visible", bVisible && !bMinimized);
+		const QPoint& wpos  = pWidget->pos();
+		const QSize&  wsize = pWidget->size();
+		if (!bVisible) bVisible = pWidget->isVisible();
+		m_settings.setValue("/x", wpos.x());
+		m_settings.setValue("/y", wpos.y());
+		m_settings.setValue("/width", wsize.width());
+		m_settings.setValue("/height", wsize.height());
+		m_settings.setValue("/visible", bVisible && !bStartMinimized);
 		m_settings.endGroup();
 	}
 }
