@@ -1,7 +1,7 @@
 // qsynthOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,6 +44,10 @@ public:
 	// Default destructor.
 	~qsynthOptions();
 
+	// Explicit I/O methods.
+	void loadOptions();
+	void saveOptions();
+
 	// Command line arguments parser.
 	bool parse_args(const QStringList& args);
 	// Command line usage helper.
@@ -94,8 +98,8 @@ public:
 	void saveComboBoxHistory(QComboBox *pComboBox, int iLimit = 8);
 
 	// Widget geometry persistence helper prototypes.
-	void saveWidgetGeometry(QWidget *pWidget, bool bMinimized = false);
-	void loadWidgetGeometry(QWidget *pWidget, bool bMinimized = false);
+	void saveWidgetGeometry(QWidget *pWidget, bool bVisible = false);
+	void loadWidgetGeometry(QWidget *pWidget, bool bVisible = false);
 
 private:
 
