@@ -1,7 +1,7 @@
 // qsynthOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -214,6 +214,9 @@ void qsynthOptionsForm::accept (void)
 	// Save combobox history...
 	m_pOptions->saveComboBoxHistory(m_ui.MessagesLogPathComboBox);
 
+	// Save/commit to disk.
+	m_pOptions->saveOptions();
+
 	// Just go with dialog acceptance.
 	QDialog::accept();
 }
