@@ -1,7 +1,7 @@
 // qsynthPresetForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -138,24 +138,25 @@ void qsynthPresetForm::setup ( qsynthOptions *pOptions, fluid_synth_t *pSynth, i
 		+ tr("Channel %1").arg(m_iChan + 1));
 
 	// Load bank list from actual synth stack...
+	m_ui.BankListView->setUpdatesEnabled(false);
 	m_ui.BankListView->setSortingEnabled(false);
 	m_ui.BankListView->clear();
 	fluid_preset_t preset;
 	QTreeWidgetItem *pBankItem = NULL;
 	// For all soundfonts (in reversed stack order) fill the available banks...
 	int cSoundFonts = ::fluid_synth_sfcount(m_pSynth);
-	for (int i = 0; i < cSoundFonts; i++) {
+	for (int i = 0; i < cSoundFonts; ++i) {
 		fluid_sfont_t *pSoundFont = ::fluid_synth_get_sfont(m_pSynth, i);
 		if (pSoundFont) {
-#ifdef CONFIG_FLUID_BANK_OFFSET
+		#ifdef CONFIG_FLUID_BANK_OFFSET
 			int iBankOffset = ::fluid_synth_get_bank_offset(m_pSynth, pSoundFont->id);
-#endif
+		#endif
 			pSoundFont->iteration_start(pSoundFont);
 			while (pSoundFont->iteration_next(pSoundFont, &preset)) {
 				int iBank = preset.get_banknum(&preset);
-#ifdef CONFIG_FLUID_BANK_OFFSET
+			#ifdef CONFIG_FLUID_BANK_OFFSET
 				iBank += iBankOffset;
-#endif
+			#endif
 				if (!findBankItem(iBank)) {
 					pBankItem = new qsynthPresetItem(m_ui.BankListView, pBankItem);
 					if (pBankItem)
@@ -165,16 +166,29 @@ void qsynthPresetForm::setup ( qsynthOptions *pOptions, fluid_synth_t *pSynth, i
 		}
 	}
 	m_ui.BankListView->setSortingEnabled(true);
+	m_ui.BankListView->setUpdatesEnabled(true);
 
 	// Set the selected bank.
 	m_iBank = 0;
+#ifdef CONFIG_FLUID_CHANNEL_INFO
+	fluid_synth_channel_info_t info;
+	::memset(&info, 0, sizeof(info));
+	::fluid_synth_get_channel_info(m_pSynth, iChan, &info);
+	if (info.assigned) {
+		m_iBank = info.bank;
+	#ifdef CONFIG_FLUID_BANK_OFFSET
+		m_iBank += ::fluid_synth_get_bank_offset(m_pSynth, info.sfont_id);
+	#endif
+	}
+#else
 	fluid_preset_t *pPreset = ::fluid_synth_get_channel_preset(m_pSynth, m_iChan);
 	if (pPreset) {
 		m_iBank = pPreset->get_banknum(pPreset);
-#ifdef CONFIG_FLUID_BANK_OFFSET
+	#ifdef CONFIG_FLUID_BANK_OFFSET
 		m_iBank += ::fluid_synth_get_bank_offset(m_pSynth, (pPreset->sfont)->id);
-#endif
+	#endif
 	}
+#endif
 
 	pBankItem = findBankItem(m_iBank);
 	m_ui.BankListView->setCurrentItem(pBankItem);
@@ -182,8 +196,14 @@ void qsynthPresetForm::setup ( qsynthOptions *pOptions, fluid_synth_t *pSynth, i
 	bankChanged();
 
 	// Set the selected program.
+#ifdef CONFIG_FLUID_CHANNEL_INFO
+	if (info.assigned)
+		m_iProg = info.program;
+#else
 	if (pPreset)
 		m_iProg = pPreset->get_num(pPreset);
+#endif
+
 	QTreeWidgetItem *pProgItem = findProgItem(m_iProg);
 	m_ui.ProgListView->setCurrentItem(pProgItem);
 //  m_ui.ProgListView->ensureItemVisible(pProgItem);
@@ -224,6 +244,7 @@ void qsynthPresetForm::setBankProg ( int iBank, int iProg )
 	// just select the synth's program preset...
 	::fluid_synth_bank_select(m_pSynth, m_iChan, iBank);
 	::fluid_synth_program_change(m_pSynth, m_iChan, iProg);
+
 	// Maybe this is needed to stabilize things around.
 	::fluid_synth_program_reset(m_pSynth);
 }
@@ -301,13 +322,14 @@ void qsynthPresetForm::bankChanged (void)
 	int iBankSelected = pBankItem->text(0).toInt();
 
 	// Clear up the program listview.
+	m_ui.ProgListView->setUpdatesEnabled(false);
 	m_ui.ProgListView->setSortingEnabled(false);
 	m_ui.ProgListView->clear();
 	fluid_preset_t preset;
 	QTreeWidgetItem *pProgItem = NULL;
 	// For all soundfonts (in reversed stack order) fill the available programs...
 	int cSoundFonts = ::fluid_synth_sfcount(m_pSynth);
-	for (int i = 0; i < cSoundFonts && !pProgItem; i++) {
+	for (int i = 0; i < cSoundFonts; ++i) {
 		fluid_sfont_t *pSoundFont = ::fluid_synth_get_sfont(m_pSynth, i);
 		if (pSoundFont) {
 #ifdef CONFIG_FLUID_BANK_OFFSET
@@ -334,6 +356,7 @@ void qsynthPresetForm::bankChanged (void)
 		}
 	}
 	m_ui.ProgListView->setSortingEnabled(true);
+	m_ui.ProgListView->setUpdatesEnabled(true);
 
 	// Stabilize the form.
 	stabilizeForm();
