@@ -1,7 +1,7 @@
 // qsynthSetup.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -85,6 +85,9 @@ public:
 	bool    bMidiDump;
 	bool    bVerbose;
 
+	// Optional options.
+	QStringList options;
+
 	// Optional file lists.
 	QStringList soundfonts;
 	QStringList bankoffsets;
