@@ -1,7 +1,7 @@
 // qsynthTabBar.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,8 +44,8 @@ qsynthTabBar::qsynthTabBar ( QWidget *pParent ) : QTabBar(pParent)
 	QTabBar::setShape(QTabBar::RoundedSouth);
 
 	if (++g_iIconRefCount == 1) {
-		g_pIconLedOn  = new QIcon(":/icons/ledon1.png");
-		g_pIconLedOff = new QIcon(":/icons/ledoff1.png");
+		g_pIconLedOn  = new QIcon(":/images/ledon1.png");
+		g_pIconLedOff = new QIcon(":/images/ledoff1.png");
 	}
 }
 
